==> arquillian-protocol-servlet-1.1.11.Final-sources.jar: org/jboss/arquillian/protocol/servlet/arq514hack/descriptors/impl/application/WebModuleImpl.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.arquillian.protocol.servlet.arq514hack.descriptors.impl.application;

import org.jboss.arquillian.protocol.servlet.arq514hack.descriptors.api.application.WebModule;

/**
 * @author <a href="mailto:lincolnbaxter@gmail.com">Lincoln Baxter, III</a>
 * 
 */
public class WebModuleImpl implements WebModule
{
   private String uri;
   private String contextRoot;

   public WebModuleImpl(String webUri, String contextRoot)
   {
      uri = webUri;
      this.contextRoot = contextRoot;
   }

   @Override
   public String getUri()
   {
      return uri;
   }

   @Override
   public String getContextRoot()
   {
      return contextRoot;
   }

   @Override
   public void setUri(String uri)
   {
      this.uri = uri;
   }

   @Override
   public void setContextRoot(String contextRoot)
   {
      this.contextRoot = contextRoot;
   }

}

==> arquillian-protocol-servlet-1.2.0.Final-sources.jar: org/jboss/arquillian/protocol/servlet/arq514hack/descriptors/impl/application/WebModuleImpl.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.arquillian.protocol.servlet.arq514hack.descriptors.impl.application;

import org.jboss.arquillian.protocol.servlet.arq514hack.descriptors.api.application.WebModule;

/**
 * @author <a href="mailto:lincolnbaxter@gmail.com">Lincoln Baxter, III</a>
 */
public class WebModuleImpl implements WebModule {
    private String uri;
    private String contextRoot;

    public WebModuleImpl(String webUri, String contextRoot) {
        uri = webUri;
        this.contextRoot = contextRoot;
    }

    @Override
    public String getUri() {
        return uri;
    }

    @Override
    public void setUri(String uri) {
        this.uri = uri;
    }

    @Override
    public String getContextRoot() {
        return contextRoot;
    }

    @Override
    public void setContextRoot(String contextRoot) {
        this.contextRoot = contextRoot;
    }
}
